import{C as e,_ as p}from"./View.vue_vue_type_script_setup_true_lang-CUdrFyoC.js";import{e as i,n,g as s,p as m}from"./jwt-decode.esm-2WRMmv_p.js";import{u as c}from"./projectStore-CuKV0FT5.js";import"./router-IuLubLUz.js";import"./ts.worker-8stLfgNB.js";import"./fetch-Db6Jgodg.js";import"./tables-Gjgiloy7.js";import"./string-leyGvoqU.js";import"./SaveButton-CttxC6Xl.js";import"./ExclamationCircleOutlined-C5YlWvhN.js";import"./CrudView-DbPYRcV6.js";import"./DocsButton.vue_vue_type_script_setup_true_lang-Dl9KxM9Y.js";import"./constants-Bm13yhKZ.js";import"./url-DOgr-bCM.js";import"./PhDotsThreeVertical.vue-DFPuBbY6.js";import"./index-CbMHALHw.js";import"./asyncComputed-8NahW-yf.js";import"./PhPencil.vue-BxOqh4JM.js";import"./useCodebaseEvents-fA9_cvft.js";import"./contracts.generated-BwcPgCI2.js";import"./index-AtWyCOub.js";import"./project-D0kM52L9.js";import"./organizationSwitcher-PvK8DFy0.js";import"./organization-D4MOj2id.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="cd255001-b783-4c9f-9d4d-c1bb0a8679cc",o._sentryDebugIdIdentifier="sentry-dbid-cd255001-b783-4c9f-9d4d-c1bb0a8679cc")}catch{}})();const z=i({__name:"EnvVars",setup(o){const r=c(),t=new e(r.projectId);return(a,d)=>(s(),n(p,{"env-var-repository":m(t),mode:"console"},null,8,["env-var-repository"]))}});export{z as default};
//# sourceMappingURL=EnvVars-Ryqewam8.js.map
