import{B as l}from"./BaseLayout-TavkU2vf.js";import{C as p}from"./ContentLayout-juwT9FxW.js";import{e as f,ak as _,b as i,H as g,a6 as b,n as r,g as s,w as m,v as y,j as w}from"./jwt-decode.esm-2WRMmv_p.js";import{_ as v}from"./BillingAlert.vue_vue_type_script_setup_true_lang-RB8sVxcQ.js";import{u as z}from"./projectsStore-q03aj06h.js";import"./router-IuLubLUz.js";import"./ts.worker-8stLfgNB.js";import"./index-AtWyCOub.js";import"./member-DxfCO0Iz.js";import"./organization-D4MOj2id.js";import"./project-D0kM52L9.js";import"./tables-Gjgiloy7.js";import"./string-leyGvoqU.js";import"./cascaderStore-DNSVgnup.js";import"./organizationSwitcher-PvK8DFy0.js";import"./ant-design-eP2Udmqs.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="de749a03-05c6-4eff-9e20-bae52aa8d766",t._sentryDebugIdIdentifier="sentry-dbid-de749a03-05c6-4eff-9e20-bae52aa8d766")}catch{}})();const P=f({__name:"Organization",setup(t){const e=_(),a=z(),n=i(()=>e.params.organizationId);g(n,o=>{o&&a.fetchedState?.organization?.id!==o&&a.fetchState(o)},{immediate:!0});const u=i(()=>a.fetchedState?.organization),d=i(()=>u.value?.billingMetadata);return(o,h)=>{const c=b("RouterView");return s(),r(l,null,{content:m(()=>[y(p,null,{default:m(()=>[d.value?(s(),r(v,{key:0,"billing-metadata":d.value,"organization-id":n.value},null,8,["billing-metadata","organization-id"])):w("",!0),(s(),r(c,{key:n.value}))]),_:1})]),_:1})}}});export{P as default};
//# sourceMappingURL=Organization-DjbVf0NO.js.map
