import{_ as c}from"./Login.vue_vue_type_script_setup_true_lang-TOTvESsw.js";import{e as d,f as i,v as u,p as n,ag as m,ak as l,g as f,aO as _}from"./jwt-decode.esm-2WRMmv_p.js";import{u as g}from"./workspaceStore-DgR_c-Xj.js";import"./OTPInput-XmxNvmTx.js";import"./Logo-Dfwlk7jl.js";import"./string-leyGvoqU.js";import"./CircularLoading-BCSBOL_5.js";import"./index-AtWyCOub.js";import"./userStore-BKKiN9EA.js";import"./runnerData-7Qe3cigA.js";import"./url-DOgr-bCM.js";import"./colorHelpers-Cdr2_S3e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="08d14d6e-f208-466a-8797-6208916ade91",e._sentryDebugIdIdentifier="sentry-dbid-08d14d6e-f208-466a-8797-6208916ade91")}catch{}})();const y={class:"runner"},b=d({__name:"Login",setup(e){const o=m(),r=l(),t=g(),p=async()=>{const{redirect:a,...s}=r.query;if(a){await o.push({path:a,query:s,params:r.params});return}o.push({name:"playerHome",query:s})};return(a,s)=>(f(),i("div",y,[u(c,{"logo-url":n(t).state.workspace?.logoUrl??void 0,"brand-name":n(t).state.workspace?.brandName,locale:n(t).state.workspace?.language??"en",onDone:p},null,8,["logo-url","brand-name","locale"])]))}}),R=_(b,[["__scopeId","data-v-12c690e1"]]);export{R as default};
//# sourceMappingURL=Login-CDR-Z_6Y.js.map
