import{N as c}from"./Navbar-BvRpJ0rX.js";import{e as d,ak as u,b as a,l,a6 as f,f as _,g as b,v as p,k as y,aO as I}from"./jwt-decode.esm-2WRMmv_p.js";import"./logo-BiWG9_W5.js";import"./AbstraButton.vue_vue_type_script_setup_true_lang-BijsII0l.js";import"./constants-Bm13yhKZ.js";import"./PhCaretDown.vue-D814-djG.js";import"./PhPencilSimple.vue-B8uOx3P1.js";import"./router-IuLubLUz.js";import"./ts.worker-8stLfgNB.js";import"./organization-D4MOj2id.js";import"./tables-Gjgiloy7.js";import"./string-leyGvoqU.js";import"./keyboard-W97AJXAk.js";import"./os-uMpa3vkB.js";import"./projectStore-CuKV0FT5.js";import"./project-D0kM52L9.js";import"./organizationSwitcher-PvK8DFy0.js";import"./cascaderStore-DNSVgnup.js";import"./CreateProjectModal.vue_vue_type_script_setup_true_lang-CA3zH3lN.js";import"./member-DxfCO0Iz.js";import"./index-Dfn3720b.js";import"./index-BWO3VDEJ.js";import"./CreateTableModal.vue_vue_type_script_setup_true_lang-BnU4qgNF.js";import"./PhNotePencil.vue-kANZKlbK.js";import"./PhSignOut.vue-CD-z7A82.js";import"./index-CbMHALHw.js";import"./index--3pHhDqj.js";import"./PhPlus.vue-C_nAbt8Y.js";import"./omniChatStore-epnbsQHY.js";import"./contracts.generated-BwcPgCI2.js";import"./runnerData-7Qe3cigA.js";import"./url-DOgr-bCM.js";import"./colorHelpers-Cdr2_S3e.js";import"./uuid-CmR7lU4f.js";import"./PhCopySimple.vue-DgYaGYTa.js";import"./PhSparkle.vue-Sn2WuXv-.js";import"./index-8Bs4w-IU.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="eb3fbf44-07ab-45a0-92fb-aede5118592b",e._sentryDebugIdIdentifier="sentry-dbid-eb3fbf44-07ab-45a0-92fb-aede5118592b")}catch{}})();const v={class:"console-layout"},g={class:"console-content"},w=d({__name:"ConsoleLayout",setup(e){const o=u(),s=a(()=>!!o.params.projectId),n=a(()=>{const t=o.meta.pageNameKey;if(t)return t.startsWith("i18n_")?l.translateIfFound(t,null):t}),m=a(()=>{const t=o.params.projectId,i=o.params.tableId,r=o.params.organizationId;if(t)return{projectId:t,tableId:i,currentPageName:n.value};if(r)return{organizationId:r}});return(t,i)=>{const r=f("RouterView");return b(),_("div",v,[p(c,{"use-cascader":!0,"cascader-props":m.value,"show-ai-sparkles":s.value},null,8,["cascader-props","show-ai-sparkles"]),y("div",g,[p(r)])])}}}),so=I(w,[["__scopeId","data-v-62f8634d"]]);export{so as default};
//# sourceMappingURL=ConsoleLayout-D2ZjQLDW.js.map
