import{P as g}from"./PlayerNavbar-qENwOMer.js";import{e as _,ak as i,r as h,b,f as k,n as y,j as w,k as v,p as a,v as L,a6 as C,ag as I,g as c,aO as N}from"./jwt-decode.esm-2WRMmv_p.js";import{u as V}from"./workspaceStore-DgR_c-Xj.js";import"./userStore-BKKiN9EA.js";import"./metadata-BQCo3INh.js";import"./PhCursorClick.vue-Ki1bxrF4.js";import"./PhHouse.vue-CA5MCcdU.js";import"./PhMagnifyingGlass.vue-DnIA0y27.js";import"./PhWebhooksLogo.vue-CJ-dnwRv.js";import"./LoadingOutlined-D6KY352f.js";import"./PhSignOut.vue-CD-z7A82.js";import"./index--3pHhDqj.js";import"./runnerData-7Qe3cigA.js";import"./url-DOgr-bCM.js";import"./colorHelpers-Cdr2_S3e.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="10e8b44b-63df-4259-8a74-5fcb03b82c89",o._sentryDebugIdIdentifier="sentry-dbid-10e8b44b-63df-4259-8a74-5fcb03b82c89")}catch{}})();const B={class:"main-container"},D={class:"content"},P=_({__name:"Main",setup(o){const e=I(),t=V(),p=i().path,n=h(null),d=async({path:r,id:s})=>{n.value=s,await e.push({path:`/${r}`}),n.value=null},u=()=>{e.push({name:"playerLogin"})},l=()=>{e.push({name:"playerLogin"})},m=b(()=>!!i().meta.hideLogin);return(r,s)=>{const f=C("RouterView");return c(),k("div",B,[a(t).state.workspace?(c(),y(g,{key:0,"current-path":a(p),"hide-login":m.value,"runner-data":a(t).state.workspace,loading:n.value,"show-sidebar":a(t).state.currentPageType==="form",onNavigate:d,onLoginClick:l,onLogoutClick:u},null,8,["current-path","hide-login","runner-data","loading","show-sidebar"])):w("",!0),v("section",D,[L(f)])])}}}),H=N(P,[["__scopeId","data-v-61bdccea"]]);export{H as default};
//# sourceMappingURL=Main-DAUF1-va.js.map
